@@ -1,3 +1,4 @@
+import socket
 import time
 import logging
 import etools.consts
@@ -30,3 +31,14 @@ def log_exec_time(func):
                     func.__name__, args, kwargs, time.time() - start)
         return result
     return inner_func
+
+
+def get_host_ip():
+    ip = None
+    try:
+        s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
+        s.connect(("8.8.8.8", 80))
+        ip = s.getsockname()[0]
+    finally:
+        s.close()
+    return ip
